
Support & Contact
=================

If you have any problems with starting PyPlanet, please report it on GitHub: https://github.com/PyPlanet/PyPlanet

If you have any problems that are maybe not that PyPlanet related, please referer to the Maniaplanet Forum: https://forum.maniaplanet.com/


Demo Servers
------------

There are several demo servers available. You need to search for servers on the following logins:

* toffestaging1
* toffestaging2


Who is behind PyPlanet
----------------------

**Organisation**:

* Toffe: Project and organisation lead.

**Core**:

* Toffe: Lead developer of the PyPlanet project.

**Apps**:

* Toffe: Bundled Application developer.
* TheM: Bundled Application developer.
* Reaby: Bundled & External Application developer.

**Testers**:

* HaagseSmurf: Tester for the PyPlanet core and apps code.

**External Contributors**

* StupsKiesel: App Contributor.
* Moski: App Contributor.

Want to help us? Contact Toffe on Discord or Forum:
:code:`Toffe#8999` or `Forum Profile <https://forum.maniaplanet.com/memberlist.php?mode=viewprofile&u=20394>`_.


Donate
======

You can support PyPlanet and other projects of Toffe (such as PyPlanet and ManiaCDN) with the following donation options:
The money will go towards hosting and paying bills for ManiaCDN, hosting test-servers for PyPlanet and other projects. When
profit is made it will be saved for bills in the future.

.. image:: https://img.shields.io/badge/patreon-donate-yellow.svg
  :target: https://patreon.com/pyplanet
.. image:: https://img.shields.io/badge/paypal-donate-yellow.svg
  :target: https://paypal.me/tomvlk
